"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict
from unkey_py.types import BaseModel


class DeleteRoleRequestBodyTypedDict(TypedDict):
    role_id: str
    r"""The id of the role you want to delete."""


class DeleteRoleRequestBody(BaseModel):
    role_id: Annotated[str, pydantic.Field(alias="roleId")]
    r"""The id of the role you want to delete."""


class DeleteRoleResponseBodyTypedDict(TypedDict):
    r"""Sucessfully deleted a role"""


class DeleteRoleResponseBody(BaseModel):
    r"""Sucessfully deleted a role"""


class DeleteRoleResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    object: NotRequired[DeleteRoleResponseBodyTypedDict]
    r"""Sucessfully deleted a role"""


class DeleteRoleResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    object: Optional[DeleteRoleResponseBody] = None
    r"""Sucessfully deleted a role"""
