"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from .v1keysverifykeyresponse import (
    V1KeysVerifyKeyResponse,
    V1KeysVerifyKeyResponseTypedDict,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict
from unkey_py.types import BaseModel


class VerifyKeyResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    v1_keys_verify_key_response: NotRequired[V1KeysVerifyKeyResponseTypedDict]
    r"""The verification result"""


class VerifyKeyResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    v1_keys_verify_key_response: Optional[V1KeysVerifyKeyResponse] = None
    r"""The verification result"""
