"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .addpermissionsop import (
    AddPermissionsPermissions,
    AddPermissionsPermissionsTypedDict,
    AddPermissionsRequestBody,
    AddPermissionsRequestBodyTypedDict,
    AddPermissionsResponse,
    AddPermissionsResponseTypedDict,
    ResponseBody,
    ResponseBodyTypedDict,
)
from .addrolesop import (
    AddRolesRequestBody,
    AddRolesRequestBodyTypedDict,
    AddRolesResponse,
    AddRolesResponseBody,
    AddRolesResponseBodyTypedDict,
    AddRolesResponseTypedDict,
    AddRolesRoles,
    AddRolesRolesTypedDict,
)
from .createapiop import (
    CreateAPIRequestBody,
    CreateAPIRequestBodyTypedDict,
    CreateAPIResponse,
    CreateAPIResponseBody,
    CreateAPIResponseBodyTypedDict,
    CreateAPIResponseTypedDict,
)
from .createidentityop import (
    CreateIdentityRatelimits,
    CreateIdentityRatelimitsTypedDict,
    CreateIdentityRequestBody,
    CreateIdentityRequestBodyTypedDict,
    CreateIdentityResponse,
    CreateIdentityResponseBody,
    CreateIdentityResponseBodyTypedDict,
    CreateIdentityResponseTypedDict,
)
from .createkeyop import (
    CreateKeyInterval,
    CreateKeyRatelimit,
    CreateKeyRatelimitTypedDict,
    CreateKeyRefill,
    CreateKeyRefillTypedDict,
    CreateKeyRequestBody,
    CreateKeyRequestBodyTypedDict,
    CreateKeyResponse,
    CreateKeyResponseBody,
    CreateKeyResponseBodyTypedDict,
    CreateKeyResponseTypedDict,
    CreateKeyType,
)
from .createpermissionop import (
    CreatePermissionRequestBody,
    CreatePermissionRequestBodyTypedDict,
    CreatePermissionResponse,
    CreatePermissionResponseBody,
    CreatePermissionResponseBodyTypedDict,
    CreatePermissionResponseTypedDict,
    Description,
    DescriptionTypedDict,
    Two,
)
from .createroleop import (
    CreateRoleDescription,
    CreateRoleDescriptionTypedDict,
    CreateRoleRequestBody,
    CreateRoleRequestBodyTypedDict,
    CreateRoleResponse,
    CreateRoleResponseBody,
    CreateRoleResponseBodyTypedDict,
    CreateRoleResponseTypedDict,
    Description2,
)
from .deleteapiop import (
    DeleteAPIRequestBody,
    DeleteAPIRequestBodyTypedDict,
    DeleteAPIResponse,
    DeleteAPIResponseBody,
    DeleteAPIResponseBodyTypedDict,
    DeleteAPIResponseTypedDict,
)
from .deleteidentityop import (
    DeleteIdentityRequestBody,
    DeleteIdentityRequestBodyTypedDict,
    DeleteIdentityResponse,
    DeleteIdentityResponseBody,
    DeleteIdentityResponseBodyTypedDict,
    DeleteIdentityResponseTypedDict,
)
from .deletekeyop import (
    DeleteKeyRequestBody,
    DeleteKeyRequestBodyTypedDict,
    DeleteKeyResponse,
    DeleteKeyResponseBody,
    DeleteKeyResponseBodyTypedDict,
    DeleteKeyResponseTypedDict,
)
from .deletekeysop import (
    DeleteKeysRequestBody,
    DeleteKeysRequestBodyTypedDict,
    DeleteKeysResponse,
    DeleteKeysResponseBody,
    DeleteKeysResponseBodyTypedDict,
    DeleteKeysResponseTypedDict,
)
from .deleteoverrideop import (
    DeleteOverrideRequestBody,
    DeleteOverrideRequestBodyTypedDict,
    DeleteOverrideResponse,
    DeleteOverrideResponseBody,
    DeleteOverrideResponseBodyTypedDict,
    DeleteOverrideResponseTypedDict,
)
from .deletepermissionop import (
    DeletePermissionRequestBody,
    DeletePermissionRequestBodyTypedDict,
    DeletePermissionResponse,
    DeletePermissionResponseBody,
    DeletePermissionResponseBodyTypedDict,
    DeletePermissionResponseTypedDict,
)
from .deleteroleop import (
    DeleteRoleRequestBody,
    DeleteRoleRequestBodyTypedDict,
    DeleteRoleResponse,
    DeleteRoleResponseBody,
    DeleteRoleResponseBodyTypedDict,
    DeleteRoleResponseTypedDict,
)
from .errbadrequest import (
    ErrBadRequest,
    ErrBadRequestCode,
    ErrBadRequestData,
    Error,
    ErrorTypedDict,
)
from .errconflict import (
    ErrConflict,
    ErrConflictCode,
    ErrConflictData,
    ErrConflictError,
    ErrConflictErrorTypedDict,
)
from .errdeleteprotected import (
    ErrDeleteProtected,
    ErrDeleteProtectedCode,
    ErrDeleteProtectedData,
    ErrDeleteProtectedError,
    ErrDeleteProtectedErrorTypedDict,
)
from .errforbidden import (
    ErrForbidden,
    ErrForbiddenCode,
    ErrForbiddenData,
    ErrForbiddenError,
    ErrForbiddenErrorTypedDict,
)
from .errinternalservererror import (
    ErrInternalServerError,
    ErrInternalServerErrorCode,
    ErrInternalServerErrorData,
    ErrInternalServerErrorError,
    ErrInternalServerErrorErrorTypedDict,
)
from .errnotfound import (
    ErrNotFound,
    ErrNotFoundCode,
    ErrNotFoundData,
    ErrNotFoundError,
    ErrNotFoundErrorTypedDict,
)
from .errpreconditionfailed import (
    ErrPreconditionFailed,
    ErrPreconditionFailedCode,
    ErrPreconditionFailedData,
    ErrPreconditionFailedError,
    ErrPreconditionFailedErrorTypedDict,
)
from .errtoomanyrequests import (
    ErrTooManyRequests,
    ErrTooManyRequestsCode,
    ErrTooManyRequestsData,
    ErrTooManyRequestsError,
    ErrTooManyRequestsErrorTypedDict,
)
from .errunauthorized import (
    ErrUnauthorized,
    ErrUnauthorizedCode,
    ErrUnauthorizedData,
    ErrUnauthorizedError,
    ErrUnauthorizedErrorTypedDict,
)
from .getapiop import (
    GetAPIRequest,
    GetAPIRequestTypedDict,
    GetAPIResponse,
    GetAPIResponseBody,
    GetAPIResponseBodyTypedDict,
    GetAPIResponseTypedDict,
)
from .getidentityop import (
    GetIdentityRatelimits,
    GetIdentityRatelimitsTypedDict,
    GetIdentityRequest,
    GetIdentityRequestTypedDict,
    GetIdentityResponse,
    GetIdentityResponseBody,
    GetIdentityResponseBodyTypedDict,
    GetIdentityResponseTypedDict,
)
from .getkeyop import (
    GetKeyRequest,
    GetKeyRequestTypedDict,
    GetKeyResponse,
    GetKeyResponseTypedDict,
)
from .getoverrideop import (
    GetOverrideRequest,
    GetOverrideRequestTypedDict,
    GetOverrideResponse,
    GetOverrideResponseBody,
    GetOverrideResponseBodyTypedDict,
    GetOverrideResponseTypedDict,
)
from .getpermissionop import (
    GetPermissionRequest,
    GetPermissionRequestTypedDict,
    GetPermissionResponse,
    GetPermissionResponseBody,
    GetPermissionResponseBodyTypedDict,
    GetPermissionResponseTypedDict,
)
from .getroleop import (
    GetRoleRequest,
    GetRoleRequestTypedDict,
    GetRoleResponse,
    GetRoleResponseBody,
    GetRoleResponseBodyTypedDict,
    GetRoleResponseTypedDict,
)
from .getverificationsop import (
    GetVerificationsIdentity,
    GetVerificationsIdentityTypedDict,
    GetVerificationsRequest,
    GetVerificationsRequestTypedDict,
    GetVerificationsResponse,
    GetVerificationsResponseBody,
    GetVerificationsResponseBodyTypedDict,
    GetVerificationsResponseTypedDict,
    GroupBy,
    GroupByTypedDict,
    KeyID,
    KeyIDTypedDict,
    One,
    Order,
    OrderBy,
    QueryParam2,
    Tag,
    TagTypedDict,
)
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from .key import (
    Identity,
    IdentityTypedDict,
    Interval,
    Key,
    KeyTypedDict,
    RatelimitModel,
    RatelimitModelTypedDict,
    Refill,
    RefillTypedDict,
    Type,
)
from .keys_getverificationsop import (
    Granularity,
    KeysGetVerificationsRequest,
    KeysGetVerificationsRequestTypedDict,
    KeysGetVerificationsResponse,
    KeysGetVerificationsResponseBody,
    KeysGetVerificationsResponseBodyTypedDict,
    KeysGetVerificationsResponseTypedDict,
    Verifications,
    VerificationsTypedDict,
)
from .limitop import (
    LimitRequestBody,
    LimitRequestBodyTypedDict,
    LimitResponse,
    LimitResponseBody,
    LimitResponseBodyTypedDict,
    LimitResponseTypedDict,
    Resources,
    ResourcesTypedDict,
)
from .listidentitiesop import (
    ListIdentitiesIdentities,
    ListIdentitiesIdentitiesTypedDict,
    ListIdentitiesRatelimits,
    ListIdentitiesRatelimitsTypedDict,
    ListIdentitiesRequest,
    ListIdentitiesRequestTypedDict,
    ListIdentitiesResponse,
    ListIdentitiesResponseBody,
    ListIdentitiesResponseBodyTypedDict,
    ListIdentitiesResponseTypedDict,
)
from .listkeysop import (
    ListKeysRequest,
    ListKeysRequestTypedDict,
    ListKeysResponse,
    ListKeysResponseBody,
    ListKeysResponseBodyTypedDict,
    ListKeysResponseTypedDict,
)
from .listoverridesop import (
    ListOverridesRequest,
    ListOverridesRequestTypedDict,
    ListOverridesResponse,
    ListOverridesResponseBody,
    ListOverridesResponseBodyTypedDict,
    ListOverridesResponseTypedDict,
    Overrides,
    OverridesTypedDict,
)
from .listpermissionsop import (
    ListPermissionsResponse,
    ListPermissionsResponseBody,
    ListPermissionsResponseBodyTypedDict,
    ListPermissionsResponseTypedDict,
)
from .listrolesop import (
    ListRolesResponse,
    ListRolesResponseBody,
    ListRolesResponseBodyTypedDict,
    ListRolesResponseTypedDict,
)
from .permissionquery import (
    And,
    AndTypedDict,
    Or,
    OrTypedDict,
    PermissionQuery,
    PermissionQueryTypedDict,
)
from .removepermissionsop import (
    RemovePermissionsPermissions,
    RemovePermissionsPermissionsTypedDict,
    RemovePermissionsRequestBody,
    RemovePermissionsRequestBodyTypedDict,
    RemovePermissionsResponse,
    RemovePermissionsResponseBody,
    RemovePermissionsResponseBodyTypedDict,
    RemovePermissionsResponseTypedDict,
)
from .removerolesop import (
    RemoveRolesRequestBody,
    RemoveRolesRequestBodyTypedDict,
    RemoveRolesResponse,
    RemoveRolesResponseBody,
    RemoveRolesResponseBodyTypedDict,
    RemoveRolesResponseTypedDict,
    RemoveRolesRoles,
    RemoveRolesRolesTypedDict,
)
from .sdkerror import SDKError
from .security import Security, SecurityTypedDict
from .setoverrideop import (
    SetOverrideRequestBody,
    SetOverrideRequestBodyTypedDict,
    SetOverrideResponse,
    SetOverrideResponseBody,
    SetOverrideResponseBodyTypedDict,
    SetOverrideResponseTypedDict,
)
from .setpermissionsop import (
    SetPermissionsPermissions,
    SetPermissionsPermissionsTypedDict,
    SetPermissionsRequestBody,
    SetPermissionsRequestBodyTypedDict,
    SetPermissionsResponse,
    SetPermissionsResponseBody,
    SetPermissionsResponseBodyTypedDict,
    SetPermissionsResponseTypedDict,
)
from .setrolesop import (
    SetRolesRequestBody,
    SetRolesRequestBodyTypedDict,
    SetRolesResponse,
    SetRolesResponseBody,
    SetRolesResponseBodyTypedDict,
    SetRolesResponseTypedDict,
    SetRolesRoles,
    SetRolesRolesTypedDict,
)
from .updateidentityop import (
    UpdateIdentityIdentitiesRatelimits,
    UpdateIdentityIdentitiesRatelimitsTypedDict,
    UpdateIdentityRatelimits,
    UpdateIdentityRatelimitsTypedDict,
    UpdateIdentityRequestBody,
    UpdateIdentityRequestBodyTypedDict,
    UpdateIdentityResponse,
    UpdateIdentityResponseBody,
    UpdateIdentityResponseBodyTypedDict,
    UpdateIdentityResponseTypedDict,
)
from .updatekeyop import (
    Roles,
    RolesTypedDict,
    UpdateKeyInterval,
    UpdateKeyPermissions,
    UpdateKeyPermissionsTypedDict,
    UpdateKeyRatelimit,
    UpdateKeyRatelimitTypedDict,
    UpdateKeyRefill,
    UpdateKeyRefillTypedDict,
    UpdateKeyRequestBody,
    UpdateKeyRequestBodyTypedDict,
    UpdateKeyResponse,
    UpdateKeyResponseBody,
    UpdateKeyResponseBodyTypedDict,
    UpdateKeyResponseTypedDict,
    UpdateKeyType,
)
from .updateremainingop import (
    Op,
    UpdateRemainingRequestBody,
    UpdateRemainingRequestBodyTypedDict,
    UpdateRemainingResponse,
    UpdateRemainingResponseBody,
    UpdateRemainingResponseBodyTypedDict,
    UpdateRemainingResponseTypedDict,
)
from .v1_livenessop import (
    Services,
    ServicesTypedDict,
    V1LivenessResponse,
    V1LivenessResponseBody,
    V1LivenessResponseBodyTypedDict,
    V1LivenessResponseTypedDict,
)
from .v1_migrations_createkeysop import (
    Hash,
    HashTypedDict,
    RequestBody,
    RequestBodyTypedDict,
    V1MigrationsCreateKeysInterval,
    V1MigrationsCreateKeysRatelimit,
    V1MigrationsCreateKeysRatelimitTypedDict,
    V1MigrationsCreateKeysRefill,
    V1MigrationsCreateKeysRefillTypedDict,
    V1MigrationsCreateKeysResponse,
    V1MigrationsCreateKeysResponseBody,
    V1MigrationsCreateKeysResponseBodyTypedDict,
    V1MigrationsCreateKeysResponseTypedDict,
    V1MigrationsCreateKeysType,
    Variant,
)
from .v1_migrations_enqueuekeysop import (
    V1MigrationsEnqueueKeysHash,
    V1MigrationsEnqueueKeysHashTypedDict,
    V1MigrationsEnqueueKeysInterval,
    V1MigrationsEnqueueKeysKeys,
    V1MigrationsEnqueueKeysKeysTypedDict,
    V1MigrationsEnqueueKeysRatelimit,
    V1MigrationsEnqueueKeysRatelimitTypedDict,
    V1MigrationsEnqueueKeysRefill,
    V1MigrationsEnqueueKeysRefillTypedDict,
    V1MigrationsEnqueueKeysRequestBody,
    V1MigrationsEnqueueKeysRequestBodyTypedDict,
    V1MigrationsEnqueueKeysResponse,
    V1MigrationsEnqueueKeysResponseBody,
    V1MigrationsEnqueueKeysResponseBodyTypedDict,
    V1MigrationsEnqueueKeysResponseTypedDict,
    V1MigrationsEnqueueKeysType,
    V1MigrationsEnqueueKeysVariant,
)
from .v1keysverifykeyrequest import (
    Authorization,
    AuthorizationTypedDict,
    RatelimitsModel,
    RatelimitsModelTypedDict,
    Remaining,
    RemainingTypedDict,
    V1KeysVerifyKeyRequest,
    V1KeysVerifyKeyRequestRatelimit,
    V1KeysVerifyKeyRequestRatelimitTypedDict,
    V1KeysVerifyKeyRequestTypedDict,
)
from .v1keysverifykeyresponse import (
    Code,
    V1KeysVerifyKeyResponse,
    V1KeysVerifyKeyResponseIdentity,
    V1KeysVerifyKeyResponseIdentityTypedDict,
    V1KeysVerifyKeyResponseRatelimit,
    V1KeysVerifyKeyResponseRatelimitTypedDict,
    V1KeysVerifyKeyResponseTypedDict,
)
from .verifykeyop import VerifyKeyResponse, VerifyKeyResponseTypedDict
from .whoamiop import (
    WhoamiIdentity,
    WhoamiIdentityTypedDict,
    WhoamiRequestBody,
    WhoamiRequestBodyTypedDict,
    WhoamiResponse,
    WhoamiResponseBody,
    WhoamiResponseBodyTypedDict,
    WhoamiResponseTypedDict,
)

# Pydantic models with forward references
Or.model_rebuild()
And.model_rebuild()

__all__ = [
    "AddPermissionsPermissions",
    "AddPermissionsPermissionsTypedDict",
    "AddPermissionsRequestBody",
    "AddPermissionsRequestBodyTypedDict",
    "AddPermissionsResponse",
    "AddPermissionsResponseTypedDict",
    "AddRolesRequestBody",
    "AddRolesRequestBodyTypedDict",
    "AddRolesResponse",
    "AddRolesResponseBody",
    "AddRolesResponseBodyTypedDict",
    "AddRolesResponseTypedDict",
    "AddRolesRoles",
    "AddRolesRolesTypedDict",
    "And",
    "AndTypedDict",
    "Authorization",
    "AuthorizationTypedDict",
    "Code",
    "CreateAPIRequestBody",
    "CreateAPIRequestBodyTypedDict",
    "CreateAPIResponse",
    "CreateAPIResponseBody",
    "CreateAPIResponseBodyTypedDict",
    "CreateAPIResponseTypedDict",
    "CreateIdentityRatelimits",
    "CreateIdentityRatelimitsTypedDict",
    "CreateIdentityRequestBody",
    "CreateIdentityRequestBodyTypedDict",
    "CreateIdentityResponse",
    "CreateIdentityResponseBody",
    "CreateIdentityResponseBodyTypedDict",
    "CreateIdentityResponseTypedDict",
    "CreateKeyInterval",
    "CreateKeyRatelimit",
    "CreateKeyRatelimitTypedDict",
    "CreateKeyRefill",
    "CreateKeyRefillTypedDict",
    "CreateKeyRequestBody",
    "CreateKeyRequestBodyTypedDict",
    "CreateKeyResponse",
    "CreateKeyResponseBody",
    "CreateKeyResponseBodyTypedDict",
    "CreateKeyResponseTypedDict",
    "CreateKeyType",
    "CreatePermissionRequestBody",
    "CreatePermissionRequestBodyTypedDict",
    "CreatePermissionResponse",
    "CreatePermissionResponseBody",
    "CreatePermissionResponseBodyTypedDict",
    "CreatePermissionResponseTypedDict",
    "CreateRoleDescription",
    "CreateRoleDescriptionTypedDict",
    "CreateRoleRequestBody",
    "CreateRoleRequestBodyTypedDict",
    "CreateRoleResponse",
    "CreateRoleResponseBody",
    "CreateRoleResponseBodyTypedDict",
    "CreateRoleResponseTypedDict",
    "DeleteAPIRequestBody",
    "DeleteAPIRequestBodyTypedDict",
    "DeleteAPIResponse",
    "DeleteAPIResponseBody",
    "DeleteAPIResponseBodyTypedDict",
    "DeleteAPIResponseTypedDict",
    "DeleteIdentityRequestBody",
    "DeleteIdentityRequestBodyTypedDict",
    "DeleteIdentityResponse",
    "DeleteIdentityResponseBody",
    "DeleteIdentityResponseBodyTypedDict",
    "DeleteIdentityResponseTypedDict",
    "DeleteKeyRequestBody",
    "DeleteKeyRequestBodyTypedDict",
    "DeleteKeyResponse",
    "DeleteKeyResponseBody",
    "DeleteKeyResponseBodyTypedDict",
    "DeleteKeyResponseTypedDict",
    "DeleteKeysRequestBody",
    "DeleteKeysRequestBodyTypedDict",
    "DeleteKeysResponse",
    "DeleteKeysResponseBody",
    "DeleteKeysResponseBodyTypedDict",
    "DeleteKeysResponseTypedDict",
    "DeleteOverrideRequestBody",
    "DeleteOverrideRequestBodyTypedDict",
    "DeleteOverrideResponse",
    "DeleteOverrideResponseBody",
    "DeleteOverrideResponseBodyTypedDict",
    "DeleteOverrideResponseTypedDict",
    "DeletePermissionRequestBody",
    "DeletePermissionRequestBodyTypedDict",
    "DeletePermissionResponse",
    "DeletePermissionResponseBody",
    "DeletePermissionResponseBodyTypedDict",
    "DeletePermissionResponseTypedDict",
    "DeleteRoleRequestBody",
    "DeleteRoleRequestBodyTypedDict",
    "DeleteRoleResponse",
    "DeleteRoleResponseBody",
    "DeleteRoleResponseBodyTypedDict",
    "DeleteRoleResponseTypedDict",
    "Description",
    "Description2",
    "DescriptionTypedDict",
    "ErrBadRequest",
    "ErrBadRequestCode",
    "ErrBadRequestData",
    "ErrConflict",
    "ErrConflictCode",
    "ErrConflictData",
    "ErrConflictError",
    "ErrConflictErrorTypedDict",
    "ErrDeleteProtected",
    "ErrDeleteProtectedCode",
    "ErrDeleteProtectedData",
    "ErrDeleteProtectedError",
    "ErrDeleteProtectedErrorTypedDict",
    "ErrForbidden",
    "ErrForbiddenCode",
    "ErrForbiddenData",
    "ErrForbiddenError",
    "ErrForbiddenErrorTypedDict",
    "ErrInternalServerError",
    "ErrInternalServerErrorCode",
    "ErrInternalServerErrorData",
    "ErrInternalServerErrorError",
    "ErrInternalServerErrorErrorTypedDict",
    "ErrNotFound",
    "ErrNotFoundCode",
    "ErrNotFoundData",
    "ErrNotFoundError",
    "ErrNotFoundErrorTypedDict",
    "ErrPreconditionFailed",
    "ErrPreconditionFailedCode",
    "ErrPreconditionFailedData",
    "ErrPreconditionFailedError",
    "ErrPreconditionFailedErrorTypedDict",
    "ErrTooManyRequests",
    "ErrTooManyRequestsCode",
    "ErrTooManyRequestsData",
    "ErrTooManyRequestsError",
    "ErrTooManyRequestsErrorTypedDict",
    "ErrUnauthorized",
    "ErrUnauthorizedCode",
    "ErrUnauthorizedData",
    "ErrUnauthorizedError",
    "ErrUnauthorizedErrorTypedDict",
    "Error",
    "ErrorTypedDict",
    "GetAPIRequest",
    "GetAPIRequestTypedDict",
    "GetAPIResponse",
    "GetAPIResponseBody",
    "GetAPIResponseBodyTypedDict",
    "GetAPIResponseTypedDict",
    "GetIdentityRatelimits",
    "GetIdentityRatelimitsTypedDict",
    "GetIdentityRequest",
    "GetIdentityRequestTypedDict",
    "GetIdentityResponse",
    "GetIdentityResponseBody",
    "GetIdentityResponseBodyTypedDict",
    "GetIdentityResponseTypedDict",
    "GetKeyRequest",
    "GetKeyRequestTypedDict",
    "GetKeyResponse",
    "GetKeyResponseTypedDict",
    "GetOverrideRequest",
    "GetOverrideRequestTypedDict",
    "GetOverrideResponse",
    "GetOverrideResponseBody",
    "GetOverrideResponseBodyTypedDict",
    "GetOverrideResponseTypedDict",
    "GetPermissionRequest",
    "GetPermissionRequestTypedDict",
    "GetPermissionResponse",
    "GetPermissionResponseBody",
    "GetPermissionResponseBodyTypedDict",
    "GetPermissionResponseTypedDict",
    "GetRoleRequest",
    "GetRoleRequestTypedDict",
    "GetRoleResponse",
    "GetRoleResponseBody",
    "GetRoleResponseBodyTypedDict",
    "GetRoleResponseTypedDict",
    "GetVerificationsIdentity",
    "GetVerificationsIdentityTypedDict",
    "GetVerificationsRequest",
    "GetVerificationsRequestTypedDict",
    "GetVerificationsResponse",
    "GetVerificationsResponseBody",
    "GetVerificationsResponseBodyTypedDict",
    "GetVerificationsResponseTypedDict",
    "Granularity",
    "GroupBy",
    "GroupByTypedDict",
    "HTTPMetadata",
    "HTTPMetadataTypedDict",
    "Hash",
    "HashTypedDict",
    "Identity",
    "IdentityTypedDict",
    "Interval",
    "Key",
    "KeyID",
    "KeyIDTypedDict",
    "KeyTypedDict",
    "KeysGetVerificationsRequest",
    "KeysGetVerificationsRequestTypedDict",
    "KeysGetVerificationsResponse",
    "KeysGetVerificationsResponseBody",
    "KeysGetVerificationsResponseBodyTypedDict",
    "KeysGetVerificationsResponseTypedDict",
    "LimitRequestBody",
    "LimitRequestBodyTypedDict",
    "LimitResponse",
    "LimitResponseBody",
    "LimitResponseBodyTypedDict",
    "LimitResponseTypedDict",
    "ListIdentitiesIdentities",
    "ListIdentitiesIdentitiesTypedDict",
    "ListIdentitiesRatelimits",
    "ListIdentitiesRatelimitsTypedDict",
    "ListIdentitiesRequest",
    "ListIdentitiesRequestTypedDict",
    "ListIdentitiesResponse",
    "ListIdentitiesResponseBody",
    "ListIdentitiesResponseBodyTypedDict",
    "ListIdentitiesResponseTypedDict",
    "ListKeysRequest",
    "ListKeysRequestTypedDict",
    "ListKeysResponse",
    "ListKeysResponseBody",
    "ListKeysResponseBodyTypedDict",
    "ListKeysResponseTypedDict",
    "ListOverridesRequest",
    "ListOverridesRequestTypedDict",
    "ListOverridesResponse",
    "ListOverridesResponseBody",
    "ListOverridesResponseBodyTypedDict",
    "ListOverridesResponseTypedDict",
    "ListPermissionsResponse",
    "ListPermissionsResponseBody",
    "ListPermissionsResponseBodyTypedDict",
    "ListPermissionsResponseTypedDict",
    "ListRolesResponse",
    "ListRolesResponseBody",
    "ListRolesResponseBodyTypedDict",
    "ListRolesResponseTypedDict",
    "One",
    "Op",
    "Or",
    "OrTypedDict",
    "Order",
    "OrderBy",
    "Overrides",
    "OverridesTypedDict",
    "PermissionQuery",
    "PermissionQueryTypedDict",
    "QueryParam2",
    "RatelimitModel",
    "RatelimitModelTypedDict",
    "RatelimitsModel",
    "RatelimitsModelTypedDict",
    "Refill",
    "RefillTypedDict",
    "Remaining",
    "RemainingTypedDict",
    "RemovePermissionsPermissions",
    "RemovePermissionsPermissionsTypedDict",
    "RemovePermissionsRequestBody",
    "RemovePermissionsRequestBodyTypedDict",
    "RemovePermissionsResponse",
    "RemovePermissionsResponseBody",
    "RemovePermissionsResponseBodyTypedDict",
    "RemovePermissionsResponseTypedDict",
    "RemoveRolesRequestBody",
    "RemoveRolesRequestBodyTypedDict",
    "RemoveRolesResponse",
    "RemoveRolesResponseBody",
    "RemoveRolesResponseBodyTypedDict",
    "RemoveRolesResponseTypedDict",
    "RemoveRolesRoles",
    "RemoveRolesRolesTypedDict",
    "RequestBody",
    "RequestBodyTypedDict",
    "Resources",
    "ResourcesTypedDict",
    "ResponseBody",
    "ResponseBodyTypedDict",
    "Roles",
    "RolesTypedDict",
    "SDKError",
    "Security",
    "SecurityTypedDict",
    "Services",
    "ServicesTypedDict",
    "SetOverrideRequestBody",
    "SetOverrideRequestBodyTypedDict",
    "SetOverrideResponse",
    "SetOverrideResponseBody",
    "SetOverrideResponseBodyTypedDict",
    "SetOverrideResponseTypedDict",
    "SetPermissionsPermissions",
    "SetPermissionsPermissionsTypedDict",
    "SetPermissionsRequestBody",
    "SetPermissionsRequestBodyTypedDict",
    "SetPermissionsResponse",
    "SetPermissionsResponseBody",
    "SetPermissionsResponseBodyTypedDict",
    "SetPermissionsResponseTypedDict",
    "SetRolesRequestBody",
    "SetRolesRequestBodyTypedDict",
    "SetRolesResponse",
    "SetRolesResponseBody",
    "SetRolesResponseBodyTypedDict",
    "SetRolesResponseTypedDict",
    "SetRolesRoles",
    "SetRolesRolesTypedDict",
    "Tag",
    "TagTypedDict",
    "Two",
    "Type",
    "UpdateIdentityIdentitiesRatelimits",
    "UpdateIdentityIdentitiesRatelimitsTypedDict",
    "UpdateIdentityRatelimits",
    "UpdateIdentityRatelimitsTypedDict",
    "UpdateIdentityRequestBody",
    "UpdateIdentityRequestBodyTypedDict",
    "UpdateIdentityResponse",
    "UpdateIdentityResponseBody",
    "UpdateIdentityResponseBodyTypedDict",
    "UpdateIdentityResponseTypedDict",
    "UpdateKeyInterval",
    "UpdateKeyPermissions",
    "UpdateKeyPermissionsTypedDict",
    "UpdateKeyRatelimit",
    "UpdateKeyRatelimitTypedDict",
    "UpdateKeyRefill",
    "UpdateKeyRefillTypedDict",
    "UpdateKeyRequestBody",
    "UpdateKeyRequestBodyTypedDict",
    "UpdateKeyResponse",
    "UpdateKeyResponseBody",
    "UpdateKeyResponseBodyTypedDict",
    "UpdateKeyResponseTypedDict",
    "UpdateKeyType",
    "UpdateRemainingRequestBody",
    "UpdateRemainingRequestBodyTypedDict",
    "UpdateRemainingResponse",
    "UpdateRemainingResponseBody",
    "UpdateRemainingResponseBodyTypedDict",
    "UpdateRemainingResponseTypedDict",
    "V1KeysVerifyKeyRequest",
    "V1KeysVerifyKeyRequestRatelimit",
    "V1KeysVerifyKeyRequestRatelimitTypedDict",
    "V1KeysVerifyKeyRequestTypedDict",
    "V1KeysVerifyKeyResponse",
    "V1KeysVerifyKeyResponseIdentity",
    "V1KeysVerifyKeyResponseIdentityTypedDict",
    "V1KeysVerifyKeyResponseRatelimit",
    "V1KeysVerifyKeyResponseRatelimitTypedDict",
    "V1KeysVerifyKeyResponseTypedDict",
    "V1LivenessResponse",
    "V1LivenessResponseBody",
    "V1LivenessResponseBodyTypedDict",
    "V1LivenessResponseTypedDict",
    "V1MigrationsCreateKeysInterval",
    "V1MigrationsCreateKeysRatelimit",
    "V1MigrationsCreateKeysRatelimitTypedDict",
    "V1MigrationsCreateKeysRefill",
    "V1MigrationsCreateKeysRefillTypedDict",
    "V1MigrationsCreateKeysResponse",
    "V1MigrationsCreateKeysResponseBody",
    "V1MigrationsCreateKeysResponseBodyTypedDict",
    "V1MigrationsCreateKeysResponseTypedDict",
    "V1MigrationsCreateKeysType",
    "V1MigrationsEnqueueKeysHash",
    "V1MigrationsEnqueueKeysHashTypedDict",
    "V1MigrationsEnqueueKeysInterval",
    "V1MigrationsEnqueueKeysKeys",
    "V1MigrationsEnqueueKeysKeysTypedDict",
    "V1MigrationsEnqueueKeysRatelimit",
    "V1MigrationsEnqueueKeysRatelimitTypedDict",
    "V1MigrationsEnqueueKeysRefill",
    "V1MigrationsEnqueueKeysRefillTypedDict",
    "V1MigrationsEnqueueKeysRequestBody",
    "V1MigrationsEnqueueKeysRequestBodyTypedDict",
    "V1MigrationsEnqueueKeysResponse",
    "V1MigrationsEnqueueKeysResponseBody",
    "V1MigrationsEnqueueKeysResponseBodyTypedDict",
    "V1MigrationsEnqueueKeysResponseTypedDict",
    "V1MigrationsEnqueueKeysType",
    "V1MigrationsEnqueueKeysVariant",
    "Variant",
    "Verifications",
    "VerificationsTypedDict",
    "VerifyKeyResponse",
    "VerifyKeyResponseTypedDict",
    "WhoamiIdentity",
    "WhoamiIdentityTypedDict",
    "WhoamiRequestBody",
    "WhoamiRequestBodyTypedDict",
    "WhoamiResponse",
    "WhoamiResponseBody",
    "WhoamiResponseBodyTypedDict",
    "WhoamiResponseTypedDict",
]
