"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict
from unkey_py.types import BaseModel
from unkey_py.utils import FieldMetadata, QueryParamMetadata


class GetRoleRequestTypedDict(TypedDict):
    role_id: str


class GetRoleRequest(BaseModel):
    role_id: Annotated[
        str,
        pydantic.Field(alias="roleId"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]


class GetRoleResponseBodyTypedDict(TypedDict):
    r"""The Role"""

    id: str
    r"""The id of the role"""
    name: str
    r"""The name of the role."""
    description: NotRequired[str]
    r"""The description of what this role does. This is just for your team, your users will not see this."""


class GetRoleResponseBody(BaseModel):
    r"""The Role"""

    id: str
    r"""The id of the role"""

    name: str
    r"""The name of the role."""

    description: Optional[str] = None
    r"""The description of what this role does. This is just for your team, your users will not see this."""


class GetRoleResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    object: NotRequired[GetRoleResponseBodyTypedDict]
    r"""The Role"""


class GetRoleResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    object: Optional[GetRoleResponseBody] = None
    r"""The Role"""
